@@ -8,7 +8,6 @@ mouse creates the mouse Class
 
 
 import numpy
-import scipy
 import random
 import pyautogui
 
@@ -29,8 +28,7 @@ mouse_dependencies = {
     'interpolate': interpolate,
     'pyautogui': pyautogui,
     'numpy': numpy,
-    'random': random,
-    'scipy': scipy
+    'random': random
 }
 mouse = Mouse(mouse_dependencies)
 
