@@ -15,7 +15,6 @@ class Mouse(object):
         self.pyautogui = dependencies['pyautogui']
         self.numpy = dependencies['numpy']
         self.random = dependencies['random']
-        self.scipy = dependencies['scipy']
 
     def move(self, dest_x, dest_y, multiplier=1):
         cp = self.get_control_points()
@@ -56,8 +55,8 @@ class Mouse(object):
         return self.numpy.linspace(y1, y2, num=cp, dtype='int')
 
     def randomise_inner_points(self, randomness, cp, dist_x, dist_y):
-        rand_x = self.scipy.random.randint(-randomness, randomness, size=cp)
-        rand_y = self.scipy.random.randint(-randomness, randomness, size=cp)
+        rand_x = self.numpy.random.randint(-randomness, randomness, size=cp)
+        rand_y = self.numpy.random.randint(-randomness, randomness, size=cp)
         rand_x[0] = rand_y[0] = rand_x[-1] = rand_y[-1] = 0
         x = dist_x + rand_x
         y = dist_y + rand_y
